Package: progresstest
Title: Testing Terminal Progress Bars
Version: 1.0.0
Authors@R: person("Gabor", "Csardi", , "csardi.gabor@gmail.com", role = c("aut", "cre"))
Description: Test progress bars from the cli package.
License: MIT + file LICENSE
Imports:
    cli
LinkingTo:
    cli
RoxygenNote: 7.1.1.9001
Encoding: UTF-8
