# Generated by roxygen2: do not edit by hand

export(test_baseline)
export(test_cli)
export(test_cli_unroll)
export(test_modulo)
export(testx)
useDynLib(progresstest, .registration = TRUE, .fixes = "c_")
