### Systemd unit files for `step`

For renewal timer documentation, see [Automating Certificate Renewal](https://smallstep.com/docs/step-ca/renewal)

For convenience, these files are redirect targets in the files.smallstep.com S3 bucket.
If you change their locations here, please update the redirects in that bucket.
