# Powershell scripts

Please note that these scripts are referenced on the `files.smallstep.com` S3 website bucket as redirects to `raw.githubusercontent.com`. If you move them, please update the S3 redirects.
