# Generated by cpp11: do not edit by hand

test_baseline_ <- function() {
  .Call(`_progresstestcpp_test_baseline_`)
}

test_cli_ <- function() {
  .Call(`_progresstestcpp_test_cli_`)
}

test_template_ <- function() {
  .Call(`_progresstestcpp_test_template_`)
}
