# spark_bar [plain]

    Code
      spark_bar(seq(0, 1, length.out = 8))
    Output
      __,,**##
    Code
      spark_bar(c(0, NA, 0.5, NA, 1))
    Output
      _ , #

# spark_bar [unicode]

    Code
      spark_bar(seq(0, 1, length.out = 8))
    Output
      ▁▂▃▄▅▆▇█
    Code
      spark_bar(c(0, NA, 0.5, NA, 1))
    Output
      ▁ ▄ █

# spark_line [plain]

    Code
      spark_line(seq(0, 1, length.out = 10))
    Output
      _,,-^

# spark_line [unicode]

    Code
      spark_line(seq(0, 1, length.out = 10))
    Output
      ⣀⡠⠔⠊⠉

