---
title: "CLI pluralization"
author: "Gábor Csárdi"
date: "`r Sys.Date()`"
output:
  rmarkdown::html_vignette:
    keep_md: true
vignette: >
  %\VignetteIndexEntry{CLI pluralization}
  %\VignetteEngine{cli::lazyrmd}
  %\VignetteEncoding{UTF-8}
---

```{r child = "../man/chunks/pluralization.Rmd"}
```
