# is_string

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

---

    Code
      stopifnot(is_string(n))
    Condition
      Error:
      ! is_string(n) is not TRUE

# is_border_style

    Code
      stopifnot(is_border_style("blahblahxxx"))
    Condition
      Error:
      ! is_border_style("blahblahxxx") is not TRUE

# is_padding_or_margin

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

---

    Code
      stopifnot(is_padding_or_margin(b))
    Condition
      Error:
      ! is_padding_or_margin(b) is not TRUE

# is_col

    Code
      stopifnot(is_col(b))
    Condition
      Error:
      ! is_col(b) is not TRUE

---

    Code
      stopifnot(is_col(b))
    Condition
      Error:
      ! is_col(b) is not TRUE

---

    Code
      stopifnot(is_col(b))
    Condition
      Error:
      ! is_col(b) is not TRUE

# is_count

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

---

    Code
      stopifnot(is_count(n))
    Condition
      Error:
      ! is_count(n) is not TRUE

