# errors

    Code
      fun()
    Condition
      Error:
      ! ! Error in a deferred `on.exit()` clause
      Caused by error in `1 + ""` at defer.R:209:7:
      ! non-numeric argument to binary operator

