% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tty.R
\name{cli_output_connection}
\alias{cli_output_connection}
\title{The connection option that cli would use}
\usage{
cli_output_connection()
}
\value{
Connection object.
}
\description{
Note that this only refers to the current R process. If the output
is produced in another process, then it is not relevant.
}
\details{
In interactive sessions the standard output is chosen, otherwise the
standard error is used. This is to avoid painting output messages red
in the R GUIs.
}
